==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/language/1/am_default/g_library_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common_g.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_document'] = 						"document";
$lang['hdr_library'] = 							"library";
$lang['hdr_page_names'] = 						"document names";
$lang['hdr_image'] = 							"photo album";



//SUBMIT BUTTONS
$lang['sub_edit'] = 							"edit";
$lang['sub_preview'] = 							"preview";
$lang['sub_save'] = 							"save";


//BODY TEXT
$lang['txt_date'] = 							"date";
$lang['txt_default'] =							"default";
$lang['txt_default_help'] =						"Each Scrapbook has a default document. When someone visits your library, the default document is the first document that someone sees.";
$lang['txt_default_set'] =						"this is set as you default document. If you want to change it, edit the document that you want to be your default document";
$lang['txt_pagename'] = 						"page name";
$lang['txt_forum_subject'] = 					"attached discussion";
$lang['txt_forum_subject_help'] = 				"Attach a discussion subject to this library document. This can be helpful in gathering feedback for your document.";
$lang['txt_level'] =							"level";
$lang['txt_none'] = 							"none";
$lang['txt_library_body'] = 					"Library item content.";
$lang['txt_library_body_help'] = 				"You must observe the group rules when publishing or editing a library item.";
$lang['txt_library_desc'] = 					"Library item description.";
$lang['txt_library_desc_help'] = 				"Give a short summary of the document. This is used on lists and summary pages.";
$lang['txt_library_title'] = 					"library title";
$lang['txt_library_title_help'] = 				"Use a decrcriptive name for your library entry.";
$lang['txt_wiki_default'] = 					"LibraryDefaultPage"; //must be WIKI formatted LikeThisExample

?>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/g_library_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'g_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_images'] = 							"images";
$lang['hdr_document'] = 						"document";
$lang['hdr_library'] = 							"library";
$lang['hdr_page_names'] = 						"document names";



//SUBMIT BUTTONS
$lang['sub_edit'] = 							"edit";
$lang['sub_preview'] = 							"preview";
$lang['sub_save'] = 							"save";


//BODY TEXT
$lang['txt_date'] = 							"date";
$lang['txt_default'] =							"default";
$lang['txt_default_help'] =						"Each Scrapbook has a default document. When someone visits your library, the default document is the first document that someone sees.";
$lang['txt_default_set'] =						"this is set as you default document. If you want to change it, edit the document that you want to be your default document";
$lang['txt_pagename'] = 						"page name";
$lang['txt_forum_subject'] = 					"attached discussion";
$lang['txt_forum_subject_help'] = 				"Attach a discussion subject to this library document. This can be helpful in gathering feedback for your document.";
$lang['txt_level'] =							"level";
$lang['txt_none'] = 							"none";
$lang['txt_library_body'] = 					"Library item content.";
$lang['txt_library_body_help'] = 				"You must observe the group rules when publishing or editing a library item.";
$lang['txt_library_desc'] = 					"Library item description.";
$lang['txt_library_desc_help'] = 				"Give a short summary of the document. This is used on lists and summary pages.";
$lang['txt_library_title'] = 					"library title";
$lang['txt_library_title_help'] = 				"Use a decrcriptive name for your library entry.";
$lang['txt_images_help'] = 						"These are the images available to the group. Select one if you want it to appear next to this item.";

?>
